/**
 * Context Menu for Files/Folders
 */

class ContextMenu {
    constructor() {
        this.menu = null;
        this.currentTarget = null;
        this.init();
    }

    init() {
        // Create context menu element
        this.menu = document.createElement('div');
        this.menu.className = 'context-menu';
        this.menu.style.display = 'none';
        document.body.appendChild(this.menu);

        // Close menu on click outside
        document.addEventListener('click', (e) => {
            if (this.menu.style.display === 'block') {
                this.hideMenu();
            }
        });

        // Prevent default context menu
        document.addEventListener('contextmenu', (e) => {
            if (e.target.closest('.file-item, .folder-item')) {
                e.preventDefault();
                this.showMenu(e);
            }
        });

        // Close on escape key
        document.addEventListener('keydown', (e) => {
            if (e.key === 'Escape' && this.menu.style.display === 'block') {
                this.hideMenu();
            }
        });
    }

    showMenu(e) {
        // Get target item
        this.currentTarget = e.target.closest('.file-item, .folder-item');
        const itemId = this.currentTarget.dataset.id;
        const itemType = this.currentTarget.classList.contains('folder-item') ? 'folder' : 'file';
        const itemName = this.currentTarget.querySelector('.item-name').textContent;

        // Create menu items based on item type
        this.menu.innerHTML = '';

        if (itemType === 'folder') {
            // Folder actions
            this.addMenuItem('Open', 'fa-folder-open', () => {
                window.location.href = `/files/browse/${itemId}`;
            });

            this.addMenuItem('Rename', 'fa-edit', () => {
                openModal('rename-modal');
                document.getElementById('new-name').value = itemName;
                window.selectedItemId = itemId;
            });

            this.addMenuItem('Delete', 'fa-trash-alt', () => {
                openModal('delete-modal');
                window.selectedItemId = itemId;
            });
        } else {
            // File actions
            this.addMenuItem('Download', 'fa-download', () => {
                window.location.href = `/files/download/${itemId}`;
            });

            this.addMenuItem('View', 'fa-eye', () => {
                window.location.href = `/files/view/${itemId}`;
            });

            this.addMenuItem('Rename', 'fa-edit', () => {
                openModal('rename-modal');
                document.getElementById('new-name').value = itemName;
                window.selectedItemId = itemId;
            });

            this.addMenuItem('Delete', 'fa-trash-alt', () => {
                openModal('delete-modal');
                window.selectedItemId = itemId;
            });
        }

        // Position menu
        const x = e.clientX;
        const y = e.clientY;

        // Set menu position
        this.menu.style.left = `${x}px`;
        this.menu.style.top = `${y}px`;

        // Show menu with animation
        this.menu.style.display = 'block';

        // Adjust position if menu goes off screen
        const menuRect = this.menu.getBoundingClientRect();
        const windowWidth = window.innerWidth;
        const windowHeight = window.innerHeight;

        if (menuRect.right > windowWidth) {
            this.menu.style.left = `${windowWidth - menuRect.width - 10}px`;
        }

        if (menuRect.bottom > windowHeight) {
            this.menu.style.top = `${windowHeight - menuRect.height - 10}px`;
        }
    }

    hideMenu() {
        this.menu.style.display = 'none';
        this.currentTarget = null;
    }

    addMenuItem(label, icon, action) {
        const item = document.createElement('div');
        item.className = 'context-menu-item';
        item.innerHTML = `<i class="fas ${icon}"></i> ${label}`;

        item.addEventListener('click', (e) => {
            e.stopPropagation();
            this.hideMenu();
            action();
        });

        this.menu.appendChild(item);
    }

    addDivider() {
        const divider = document.createElement('div');
        divider.className = 'context-menu-divider';
        this.menu.appendChild(divider);
    }
}

// Initialize context menu
document.addEventListener('DOMContentLoaded', function () {
    window.contextMenu = new ContextMenu();
});

// Context menu for files browser
document.addEventListener('DOMContentLoaded', function () {
    const filesContainer = document.getElementById('files-container');
    const contextMenu = document.getElementById('context-menu');

    if (!filesContainer || !contextMenu) return;

    // Track if click was on empty space
    let clickedOnEmptySpace = false;

    // Context menu options for empty space
    const emptySpaceOptions = [
        {
            label: 'New Folder',
            icon: 'fa-folder-plus',
            action: function () {
                // Get the current folder ID from the URL or data attribute
                const urlParams = new URLSearchParams(window.location.search);
                const currentFolderId = urlParams.get('folder_id');

                // Show the new folder modal
                const newFolderModal = document.getElementById('new-folder-modal');
                const parentIdInput = document.getElementById('parent_id');

                if (newFolderModal) {
                    // Set the parent folder ID if available
                    if (parentIdInput && currentFolderId) {
                        parentIdInput.value = currentFolderId;
                    } else if (parentIdInput) {
                        parentIdInput.value = '';
                    }

                    newFolderModal.classList.add('active');

                    // Focus on the folder name input
                    const folderNameInput = document.getElementById('folder_name');
                    if (folderNameInput) {
                        folderNameInput.focus();
                    }
                }
            }
        },
        {
            label: 'Upload Files',
            icon: 'fa-upload',
            action: function () {
                const fileInput = document.getElementById('file-upload');
                if (fileInput) {
                    fileInput.click();
                }
            }
        },
        {
            label: 'Paste',
            icon: 'fa-paste',
            action: function () {
                pasteItems();
            },
            condition: function () {
                // Only show if items are in clipboard
                return sessionStorage.getItem('clipboard') !== null;
            }
        },
        {
            label: 'Select All',
            icon: 'fa-object-group',
            action: function () {
                selectAllItems();
            }
        },
        {
            label: 'Refresh',
            icon: 'fa-sync-alt',
            action: function () {
                window.location.reload();
            }
        }
    ];

    // File/folder specific options
    const itemOptions = [
        // ... existing item options ...
    ];

    // Handle right click on container
    filesContainer.addEventListener('contextmenu', function (e) {
        // Check if click was on empty space
        clickedOnEmptySpace = e.target === filesContainer || e.target.classList.contains('files-container-inner');

        if (clickedOnEmptySpace) {
            e.preventDefault();
            const options = emptySpaceOptions.filter(option =>
                typeof option.condition !== 'function' || option.condition());

            showContextMenu(e.clientX, e.clientY, options);
        }
    });

    // Show context menu with provided options
    function showContextMenu(x, y, options) {
        // Clear existing menu
        contextMenu.innerHTML = '';

        // Create menu items
        options.forEach(option => {
            const menuItem = document.createElement('div');
            menuItem.className = 'context-menu-item';

            const icon = document.createElement('i');
            icon.className = `fas ${option.icon}`;

            const label = document.createElement('span');
            label.textContent = option.label;

            menuItem.appendChild(icon);
            menuItem.appendChild(label);

            menuItem.addEventListener('click', function () {
                // Hide menu
                contextMenu.style.display = 'none';
                // Execute action
                option.action();
            });

            contextMenu.appendChild(menuItem);
        });

        // Position menu
        contextMenu.style.left = `${x}px`;
        contextMenu.style.top = `${y}px`;
        contextMenu.style.display = 'block';

        // Adjust position if menu is out of viewport
        const rect = contextMenu.getBoundingClientRect();
        if (rect.right > window.innerWidth) {
            contextMenu.style.left = `${x - rect.width}px`;
        }
        if (rect.bottom > window.innerHeight) {
            contextMenu.style.top = `${y - rect.height}px`;
        }
    }

    // Close context menu when clicking outside
    document.addEventListener('click', function () {
        contextMenu.style.display = 'none';
    });
}); 